@@ -84,6 +84,7 @@ typedef struct fmgr_plpgsql_cache
 
 	Oid			funcid;
 	bool		is_plpgsql;
+	bool		is_late;
 	Datum		arg;
 
 	void	   *plugin2_info[MAX_PLDBGAPI2_PLUGINS];
@@ -828,9 +829,20 @@ pldbgapi2_func_setup(PLpgSQL_execstate *estate, PLpgSQL_function *func)
 	func_info_entry *func_info;
 	int			i;
 
-	Assert(fcache_plpgsql->magic == FMGR_CACHE_MAGIC);
-	Assert(fcache_plpgsql);
-	Assert(fcache_plpgsql->is_plpgsql);
+	/*
+	 * Initialize fmgr_plpgsql_cache, when fmgr hook is not called
+	 * in expected order (usually when plpgsql_check is initialized
+	 * inside function.
+	 */
+	if (!fcache_plpgsql ||
+		fcache_plpgsql->magic != FMGR_CACHE_MAGIC ||
+		!fcache_plpgsql->is_plpgsql ||
+		((fcache_plpgsql->funcid != PLpgSQLinlineFunc) && (fcache_plpgsql->funcid != func->fn_oid)))
+	{
+		ereport(ERROR,
+				(errmsg("too late initialization of fmgr_plpgsql_cache"),
+				 errhint("Use \"load 'plpgsql_check'\" before you use plpgsql_check functionality.")));
+	}
 
 #ifdef USE_ASSERT_CHECKING
 
