@@ -230,8 +230,16 @@ extern char *plpgsql_check_get_src(HeapTuple procTuple);
 extern Oid plpgsql_check_pragma_func_oid(void);
 extern bool plpgsql_check_is_plpgsql_function(Oid foid);
 extern Oid plpgsql_check_get_op_namespace(Oid opno);
+
+#if PG_VERSION_NUM < 180000
+
 extern char *get_extension_version(Oid ext_oid);
 
+#else
+
+extern char *get_extension_version2(Oid ext_oid);
+
+#endif
 
 /*
  * functions from tablefunc.c
